%GPC Apply GPC to unstable helicopter. Example 4.11.
%
% Usage: gpcheli(pole)

function gpcheli(pole)

load helicopter % data, with observer pole at 0.8

% Write data:
M,P
ywt,uwt
tend
r=1 % Set-point
wu = [zeros(16,1);-0.03;-0.07;-0.1];

% Generate response with obs pole at 0.8, no disturbance on input:
[y8,u8]=scmpc(imod,imod,ywt,uwt,M,P,tend,r,ulim,ylim,Kest,[],[],[],[]);

% Generate response with obs pole at 0.8, with disturbance on input:
[y8w,u8w]=scmpc(imod,imod,ywt,uwt,M,P,tend,r,ulim,ylim,Kest,[],[],[],wu);

% Modify model for observer pole at 'pole':
calAnew = calA;
calAnew(1,8) = -pole;
imodnew = ss2mod(calAnew,calB,calC,calD,0.6);

% Generate response with obs pole at 'pole', no disturbance on input:
[yp,up]=scmpc(imodnew,imodnew,ywt,uwt,M,P,tend,r,ulim,ylim,Kest,[],[],[],[]);

% Generate response with obs pole at 'pole', with disturbance on input:
[ypw,upw]=scmpc(imodnew,imodnew,ywt,uwt,M,P,tend,r,ulim,ylim,Kest,[],[],[],wu);

disp(['norm(y8-yp)=',num2str(norm(y8-yp))])

% Plot results:

tvec = 0:0.6:tend;

% Plots without disturbance:
%figure
subplot(211)
plot(tvec,y8,'-')
hold on
plot(tvec,yp,'--')
xlabel('Time (seconds)')
ylabel('Output')
grid
hold off

subplot(212)
stairs(tvec,u8,'-')
hold on
stairs(tvec,up,'--')
xlabel('Time (seconds)')
ylabel('Input')
grid
hold off

% Plots with disturbance:
figure
subplot(211)
plot(tvec,y8w,'-')
hold on
plot(tvec,ypw,'--')
xlabel('Time (seconds)')
ylabel('Output')
grid

subplot(212)
stairs(tvec,u8w,'-')
hold on
stairs(tvec,upw,'--')
xlabel('Time (seconds)')
ylabel('Input')
grid

